<?php
/**
 * class permettant de regrouper un ensemble de fichier CSS ou JS dans un seul fichier CSS ou JS et de le compresser, via le composant Assetic de sf2 
 * @author ulrich, 16/08/11
 * @abstract
 *
 */
abstract class absAsset
{
	protected	$sDir,
				$aCompresseurs = array(),
				$aAssetFiles = array();

	/**
	 * cnstructeur, doit initialiser les variables de classes
	 * 
	 * @abstract
	 */
	abstract public function __construct();
	
	/**
	 * vérifie l'exsitance des fichiers et les regroupe dans un tableau de FileAsset
	 * 
	 * @author ulrich, 16/08/11
	 * @author ulrich, 29/08/11 => prise en compte des fichier avec un chemin absolue depuis la racine web
	 * @param  array $aFiles
	 * @throws clsAssetManagerException si le fichier n'existe pas.
	 */
	public function prepareSource(Array $aFiles)
	{
		for($i = 0, $n = count($aFiles); $i < $n; $i++)
		{
			$sFile = $aFiles[$i];
			if(preg_match('#^/#', $sFile) && file_exists(sfConfig::get('sf_web_dir').$sFile))
			{
				$this->aAssetFiles[] = new Assetic\Asset\FileAsset(sfConfig::get('sf_web_dir').$sFile);
			}
			elseif(file_exists($this->sDir.$sFile))
			{
				$this->aAssetFiles[] = new Assetic\Asset\FileAsset($this->sDir.$sFile);
			}
			else
			{
				throw new clsAssetManagerException('Le fichier: '.$this->sDir.$sFile.' n\'extiste pas.');	
			}
		}
		
		return $this;
	}
	
	/**
	 * Ecrit le fichier unique regroupant tous les assets
	 * 
	 * @author ulrich, 16/08/11
	 * @param  String $sFileName: nom du fichier à écrire
	 */
	public function creerAsset($sFileName)
	{
		$oAssetCol = new Assetic\Asset\AssetCollection($this->aAssetFiles, $this->aCompresseurs);
		$oAssetCol->load();
		$oAssetCol->setTargetPath($sFileName);
		
		$oWriter = new Assetic\AssetWriter($this->sDir);
		$oWriter->writeAsset($oAssetCol);
	}
}