<?php
/**
 * class permettant de parser le fichier de config assets.yml
 * 
 * @author ulrich, 16/08/11
 * @singleton
 *
 */
class clsAssetsLoader
{
	protected static $oInstance;
	
	protected $aConfig;
	
	private function __construct()
	{
		$this->aConfig = clsYaml::chargerYaml('plugins/ulAssetManagerPlugin/config/assets.yml');
		sfContext::getInstance()->getConfiguration()->loadHelpers('Asset');
	}
	
	/**
	 * 
	 * @author ulrich, 16/08/11
	 * @return clsAssetsLoader
	 */
	public static function getInstance()
	{
		if(!self::$oInstance instanceof self)
			self::$oInstance = new self();
			
		return self::$oInstance;
	}

	/**
	 * Retourne les CSS pour une application donnée (front, admin.....)
	 * 
	 * @author ulrich, 16/08/11
	 * @param  String $psApp
	 * @throws clsAssetManagerException
	 * @return String
	 */
	public function getCss($psApp = 'front')
	{
		if(!array_key_exists($psApp, $this->aConfig['css']))
			throw new clsAssetManagerException('L\'application: '.$psApp.' est introuvable pour les CSS.');
			
		if(!$this->aConfig['css'][$psApp])
			return null;
			
		$sHtml = '';
		if(!is_array($this->aConfig['css'][$psApp]))
		{
			$sHtml = stylesheet_tag($this->aConfig['css'][$psApp]);
		}
		else
		{
			for($i = 0, $n = count($this->aConfig['css'][$psApp]); $i < $n; $i++)
			{
				$sHtml .= stylesheet_tag($this->aConfig['css'][$psApp][$i]);
			}
		}
		
		return $sHtml;
	}
	
	/**
	 * Retourne les Js qui doivent être placé en haut de la page pour une application donnée (front, admin.....)
	 * Typiquement les librairies externes (Ext, jquery....)
	 * 
	 * @author ulrich, 16/08/11
	 * @param  String $psApp
	 * @throws clsAssetManagerException
	 * @return String
	 */
	public function getJsHead($psApp = 'front')
	{
		if(!array_key_exists($psApp, $this->aConfig['js']))
			throw new clsAssetManagerException('L\'application: '.$psApp.' est introuvable pour les JS.');
			
		return (!$this->aConfig['js'][$psApp]['head'])? null : $this->getJsTag($this->aConfig['js'][$psApp]['head']);
	}
	
	/**
	 * Retourne les Js qui doivent être placé en bas de la page pour une application donnée (front, admin.....)
	 * Typiquement les scripts "maison"
	 * 
	 * @author ulrich, 16/08/11
	 * @param  String $psApp
	 * @throws clsAssetManagerException
	 * @return String
	 */
	public function getJsFoot($psApp = 'front')
	{
		if(!array_key_exists($psApp, $this->aConfig['js']))
			throw new clsAssetManagerException('L\'application: '.$psApp.' est introuvable pour les JS.');
		
		return (!$this->aConfig['js'][$psApp]['foot'])? null : $this->getJsTag($this->aConfig['js'][$psApp]['foot']);
	}
	
	protected function getJsTag($aFiles)
	{			
		$sHtml = '';
		if(!is_array($aFiles))
		{
			$sHtml = javascript_include_tag($aFiles);
		}
		else
		{
			for($i = 0, $n = count($aFiles); $i < $n; $i++)
			{
				$sHtml .= javascript_include_tag($aFiles[$i]);
			}
		}
		
		return $sHtml;
	}
}