<?php
/**
 * Tache permettant de compresser les fichiers CSS et JS suivant le fichier de config assets.yml du plugin
 * 
 * 
 * @author ulrich, 16/08/11
 *
 */
class compressAssetsTask extends sfBaseTask
{
	protected $aConfig;

	protected function configure()
	{
		$this->addOption('env', null, sfCommandOption::PARAMETER_OPTIONAL, 'Changes the environment this task is run in', 'prod');
		
		$this->namespace           = 'UL';
		$this->name                = 'compressAssets';
		$this->briefDescription    = 'Compress les Assets';
		$this->detailedDescription = 'Compress les Assets pour l\'environnement de production.';
	}
	
	protected function execute($arguments = array(), $options = array())
	{
		//Chargement du context pour avoir accès à sfConfig
		require_once dirname(__FILE__).'/../../../../config/ProjectConfiguration.class.php';
		$configuration = ProjectConfiguration::getApplicationConfiguration('frontend', $options['env'], true);
		sfContext::createInstance($configuration);
		
		$this->aConfig = clsYaml::chargerYamlWithoutCache(dirname(__FIlE__).'/../../config/assets.yml');
		
		$this->compressCss();
		$this->compressJS();
		
		return 0;
	}
	
	/**
	 * Determine l'environnement qui sera la source en priorité dev => default => all
	 * 
	 * @author Ulrich, 16/08/11
	 * @return string
	 */
	protected function getSourceEnv()
	{
		if(array_key_exists('dev', $this->aConfig))
			return 'dev';
		elseif(array_key_exists('default', $this->aConfig))
			return 'default';
		elseif(array_key_exists('all', $this->aConfig))
			return 'all';
	}
	
	/**
	 * Traite le bloc CSS de chaque environnement
	 * 
	 * @author ulrich, 16/08/11
	 * @author ulrich, 29/08/11 => fix bug concatenation des fichier CSS dés la deuxième App
	 */
	protected function compressCss()
	{
		$sSource = $this->getSourceEnv();
		
		foreach($this->aConfig[$sSource]['css'] as $sApp => $aFiles)
		{
			$oAssetCSS = new clsAssetCss();
			try
			{
				$oAssetCSS->prepareSource($aFiles);
			}
			catch(clsAssetManagerException $e)
			{
				$this->logSection('Info:', $e->getMessage());
			}
			
			foreach($this->aConfig as $sEnv => $aConfig)
			{
				if($sEnv == $sSource)
					continue;
					
				if(	array_key_exists('css', $aConfig) && 
					array_key_exists($sApp, $aConfig['css']) && 
					!is_array($aConfig['css'][$sApp]) &&
					null !== $aConfig['css'][$sApp])
				{
					try
					{
						$oAssetCSS->creerAsset($aConfig['css'][$sApp]);
					}
					catch(clsAssetManagerException $e)
					{
						$this->logSection('Info:', $e->getMessage());
					}	
				}
			}
		}
	}
	
	/**
	 * traite le bloc JS de chaque environnement
	 * 
	 * @author ulrich, 16/08/11
	 * @author ulrich, 29/08/11 => fix bug concatenation des fichier js dés la deuxième App
	 */
	protected function compressJS()
	{
		$sSource = $this->getSourceEnv();
		
		foreach($this->aConfig[$sSource]['js'] as $sApp => $aPart)
		{
			$oAssetJs = new clsAssetJs();
			
			foreach($aPart as $sName => $aFiles)
			{
				try
				{
					$oAssetJs->prepareSource($aFiles);
				}
				catch(clsAssetManagerException $e)
				{
					$this->logSection('Info:', $e->getMessage());
				}
				
				foreach($this->aConfig as $sEnv => $aConfig)
				{
					if($sEnv == $sSource)
						continue;
						
					if(	array_key_exists('js', $aConfig) && 
						array_key_exists($sApp, $aConfig['js']) &&
						array_key_exists($sName, $aConfig['js'][$sApp]) &&  
						!is_array($aConfig['js'][$sApp][$sName]) &&
						null !== $aConfig['js'][$sApp][$sName])
					{
						try
						{
							$oAssetJs->creerAsset($aConfig['js'][$sApp][$sName]);
						}
						catch(clsAssetManagerException $e)
						{
							$this->logSection('Info:', $e->getMessage());
						}	
					}
				}
			}
		}
	}
}